@@ -1,5 +1,6 @@
 `skel.plot` <-
-function(rw.vec, yr.vec = NULL, sname = '', filt.weight = 9, dat.out = F)
+function(rw.vec, yr.vec = NULL, sname = '', filt.weight = 9, dat.out = FALSE,
+  master=FALSE)
 {
   if(nchar(sname) > 7) stop('sname must be a character vector less than 8 characters long')
 
@@ -133,28 +134,54 @@ function(rw.vec, yr.vec = NULL, sname = '', filt.weight = 9, dat.out = F)
     init.lab = min(skel.sub$yr)
     x.labs = seq(init.lab, length.out = length(ticks), by=10)
     for(j in 1:length(ticks)){
-      grid.text(label = x.labs[j],
-                x=unit(ticks[j]*2,'mm'),
-                y=unit(rh+1,'mm'),
-                just = c('center','bottom'),
-                gp = gpar(fontsize=10))
+      if(!master){
+        grid.text(label = x.labs[j],
+                  x=unit(ticks[j]*2,'mm'),
+                  y=unit(rh+0.5,'mm'),
+                  just = c('center','bottom'),
+                  gp = gpar(fontsize=10))
+      }
+      else {
+        grid.text(label = x.labs[j],
+                  x=unit(ticks[j]*2,'mm'),
+                  y=unit(rh-22.5,'mm'),
+                  just = c('center','top'),
+                  gp = gpar(fontsize=10))
+      }
+
     }
     # plot data
     for(j in 1:length(skel.sub$yr)){
       if(!is.na(skel.sub$skel[j])){
-        grid.lines(x=unit(c((j-1)*2,(j-1)*2),'mm'),
-          y=unit(c(0,skel.sub$skel[j]*2),'mm'),
-          gp = gpar(col = 'black',lwd = 2, lineend = 'square',
-          linejoin = 'round'))
+        if(!master){
+          grid.lines(x=unit(c((j-1)*2,(j-1)*2),'mm'),
+            y=unit(c(0,skel.sub$skel[j]*2),'mm'),
+            gp = gpar(col = 'black',lwd = 2, lineend = 'square',
+            linejoin = 'round'))
+          }
+        else{
+          grid.lines(x=unit(c((j-1)*2,(j-1)*2),'mm'),
+            y=unit(c(22,22-skel.sub$skel[j]*2),'mm'),
+            gp = gpar(col = 'black',lwd = 2, lineend = 'square',
+            linejoin = 'round'))
+          }
+
       }
       # end arrow
       if(i == max(n.rows) & j == end.yr){
         end.mm = (j-1)*2
         grid.lines(x=unit(c(end.mm,end.mm),'mm'),y=unit(c(rh,0),'mm'),
                    gp = gpar(lwd = 2, lineend = 'square', linejoin = 'round'))
-        grid.polygon(x=unit(c(end.mm,end.mm,end.mm+2), 'mm'),
-                     y=unit(c(0, 6, 6), 'mm'),
-                     gp=gpar(fill = 'black', lineend = 'square', linejoin = 'round'))
+        if(!master){
+          grid.polygon(x=unit(c(end.mm,end.mm,end.mm+2), 'mm'),
+                       y=unit(c(0, 6, 6), 'mm'),
+                       gp=gpar(fill = 'black', lineend = 'square', linejoin = 'round'))
+        }
+        else{
+          grid.polygon(x=unit(c(end.mm,end.mm,end.mm+2), 'mm'),
+                       y=unit(c(rh, 16, 16), 'mm'),
+                       gp=gpar(fill = 'black', lineend = 'square', linejoin = 'round'))
+        }
       }
     }
     # start arrow and sample id
@@ -162,16 +189,32 @@ function(rw.vec, yr.vec = NULL, sname = '', filt.weight = 9, dat.out = F)
       start.mm = pad.length*2
       grid.lines(x=unit(c(start.mm,start.mm),'mm'),y=unit(c(rh,0),'mm'),
                  gp = gpar(lwd = 2, lineend = 'square', linejoin = 'round'))
-      grid.polygon(x=unit(c(start.mm, start.mm, start.mm-2), 'mm'),
-                   y=unit(c(0, 6, 6), 'mm'),
-                   gp=gpar(fill = 'black', lineend = 'square', linejoin = 'round'))
-      # sample id
-      grid.text(label = sname,
-                x=unit(start.mm-1,'mm'),
-                y=unit(rh-2,'mm'),
-                just = c('right','bottom'),
-                rot = 90,
-                gp = gpar(fontsize=10))
+      if(!master){
+        grid.polygon(x=unit(c(start.mm, start.mm, start.mm-2), 'mm'),
+                     y=unit(c(0, 6, 6), 'mm'),
+                     gp=gpar(fill = 'black', lineend = 'square', linejoin = 'round'))
+        # sample id
+        fontsize.sname = ifelse(nchar(sname) > 6, 9, 10)
+        grid.text(label = sname,
+                  x=unit(start.mm-1,'mm'),
+                  y=unit(rh-1,'mm'),
+                  just = c('right','bottom'),
+                  rot = 90,
+                  gp = gpar(fontsize=fontsize.sname))
+      }
+      else{
+        grid.polygon(x=unit(c(start.mm, start.mm, start.mm-2), 'mm'),
+                     y=unit(c(rh, 16, 16), 'mm'),
+                     gp=gpar(fill = 'black', lineend = 'square', linejoin = 'round'))
+        # sample id
+        fontsize.sname = ifelse(nchar(sname) > 6, 9, 10)
+        grid.text(label = sname,
+                  x=unit(start.mm-1,'mm'),
+                  y=unit(1,'mm'),
+                  just = c('left','bottom'),
+                  rot = 90,
+                  gp = gpar(fontsize=fontsize.sname))
+      }
 
     }
 
